#pragma once

#include "ATRInterface.h"
#include "ATRLanguage.h"
#include "resource.h"       // main symbols


#if defined(_WIN32_WCE) && !defined(_CE_DCOM) && !defined(_CE_ALLOW_SINGLE_THREADED_OBJECTS_IN_MTA)
#error "Single-threaded COM objects are not properly supported on Windows CE platform, such as the Windows Mobile platforms that do not include full DCOM support. Define _CE_ALLOW_SINGLE_THREADED_OBJECTS_IN_MTA to force ATL to support creating single-thread COM object's and allow use of it's single-threaded COM object implementations. The threading model in your rgs file was set to 'Free' as that is the only threading model supported in non DCOM Windows CE platforms."
#endif

/***************************************************************************************************/
// Class CATRDialog
/***************************************************************************************************/
/// 
/// \ingroup ATRInterface
///
/// \brief Coclass that implements IATRDialog interface.
///
///   Interface includes methods to e.g. translate dialog box controls to different language.
///   Interface also supports context sensitive help and tooltips. Dialog box look and feel can be
///   aso modified easily.
///
/// \author tsalonen
///
/// \date 07.06.2006
/***************************************************************************************************/

class ATL_NO_VTABLE CATRDialog :
	public CComObjectRootEx<CComSingleThreadModel>,
	public CComCoClass<CATRDialog, &CLSID_ATRDialog>,
  public IATRLanguageImpl<IDispatchImpl<IATRDialog, &IID_IATRDialog, &LIBID_ATRInterfaceLib>>
{
public:
	CATRDialog()
	{
	}

  DECLARE_REGISTRY_RESOURCEID(IDR_ATRDIALOG)


BEGIN_COM_MAP(CATRDialog)
	COM_INTERFACE_ENTRY(IATRDialog)
	COM_INTERFACE_ENTRY(IDispatch)
END_COM_MAP()

	DECLARE_PROTECT_FINAL_CONSTRUCT()


	/***************************************************************************************************/
	//* FinalConstruct
	/***************************************************************************************************/
	///
	/// \brief Called during the final stages of object construction
	///
	///   This method performs any final initialization on the m_contained member.
	///
	/// \return A standard HRESULT value.
	///
	/// \author tsalonen
	///
	/// \date 09.06.2006
	/***************************************************************************************************/

	HRESULT FinalConstruct()
	{
    mhParent = NULL;
		return S_OK;
	}


	/***************************************************************************************************/
	//* FinalRelease
	/***************************************************************************************************/
	///
	/// \brief Called during object destruction
	///
	///   This method frees the m_contained member.
	///
	/// \return A standard HRESULT value.
	///
	/// \author tsalonen
	///
	/// \date 09.06.2006
	/***************************************************************************************************/

	void FinalRelease()
	{
	}

public:
  STDMETHOD(InitDialog)(LONG lHWnd, BSTR bsGroup);
  STDMETHOD(SetStyle)(LONG lStyle);
	
  BOOL CALLBACK TranslateControl(HWND hwnd);
  static BOOL CALLBACK EnumChildStatic(HWND hwnd, LPARAM lTransParam);

  LRESULT CALLBACK HelpWndProc( HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam );
  static LRESULT CALLBACK HelpWndProcStatic( HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM lParam );

private:
  void TranslateDialogBox();

private:
  CString             moGroup;            ///< Group in LAN file from where to get translations
  CString             moHelpGroup;        ///< Group in LAN file from where to get text for context sensitive help
  CString             moOrigDlgTitle;     ///< Original title of the dialog box
  HWND                mhParent;           ///< Handle to the window managed by this interface
};

OBJECT_ENTRY_AUTO(__uuidof(ATRDialog), CATRDialog)
